@@ -1,10 +1,10 @@
 # Install and start **Vitrage** service in devstack
 #
-# To enable vitragebehaviortack add an entry to local.conf that
+# To enable vitrage behavior add an entry to local.conf that
 # looks like
 #
 # [[local|localrc]]
-# enable_plugin vitrage git://git.openstack.org/openstack/vitrage
+# enable_plugin vitrage https://git.openstack.org/openstack/vitrage
 #
 # By default all vitrage services are started (see
 # devstack/settings).
@@ -25,21 +25,13 @@ else
     VITRAGE_BIN_DIR=$(get_python_exec_prefix)
 fi
 
-if [ -z "$VITRAGE_DEPLOY" ]; then
-    # Default
-    VITRAGE_DEPLOY=simple
-
-    # Fallback to common wsgi devstack configuration
-    if [ "$ENABLE_HTTPD_MOD_WSGI_SERVICES" == "True" ]; then
-        VITRAGE_DEPLOY=mod_wsgi
-
-    # Deprecated config
-    elif [ -n "$VITRAGE_USE_MOD_WSGI" ] ; then
-        echo_summary "VITRAGE_USE_MOD_WSGI is deprecated, use VITRAGE_DEPLOY instead"
-        if [ "$VITRAGE_USE_MOD_WSGI" == True ]; then
-            VITRAGE_DEPLOY=mod_wsgi
-        fi
-    fi
+# VITRAGE_DEPLOY defines how vitrage is deployed, allowed values:
+# - mod_wsgi : Run vitrage under Apache HTTPd mod_wsgi
+# - uwsgi : Run vitrage under uwsgi
+if [[ "$WSGI_MODE" == "uwsgi" ]]; then
+    VITRAGE_DEPLOY=${VITRAGE_DEPLOY:-uwsgi}
+else
+    VITRAGE_DEPLOY=${VITRAGE_DEPLOY:-mod_wsgi}
 fi
 
 # Test if any Vitrage services are enabled
@@ -50,7 +42,11 @@ function is_vitrage_enabled {
 }
 
 function vitrage_service_url {
-    echo "$VITRAGE_SERVICE_PROTOCOL://$VITRAGE_SERVICE_HOST:$VITRAGE_SERVICE_PORT"
+    if [[ "$VITRAGE_DEPLOY" == "mod_wsgi" ]]; then
+       echo "$VITRAGE_SERVICE_PROTOCOL://$VITRAGE_SERVICE_HOST:$VITRAGE_SERVICE_PORT"
+    else
+       echo "$VITRAGE_SERVICE_PROTOCOL://$VITRAGE_SERVICE_HOST/rca"
+    fi
 }
 
 
@@ -59,7 +55,6 @@ function _vitrage_config_apache_wsgi {
     sudo mkdir -p $VITRAGE_WSGI_DIR
 
     local vitrage_apache_conf=$(apache_site_config_for vitrage)
-    local apache_version=$(get_apache_version)
     local venv_path=""
 
     # Copy proxy vhost and wsgi file
@@ -115,8 +110,10 @@ function _vitrage_cleanup_apache_wsgi {
 # cleanup_vitrage() - Remove residual data files, anything left over
 # from previous runs that a clean run would need to clean up
 function cleanup_vitrage {
-    if [ "$VITRAGE_DEPLOY" == "mod_wsgi" ]; then
+    if [[ "$VITRAGE_DEPLOY" == "mod_wsgi" ]]; then
         _vitrage_cleanup_apache_wsgi
+    else
+       remove_uwsgi_config "$VITRAGE_UWSGI_FILE" "$VITRAGE_PUBLIC_UWSGI"
     fi
 
     # delete all vitrage configurations
@@ -136,7 +133,7 @@ function disable_vitrage_datasource {
 
 # Set configuration for database backend.
 function vitrage_configure_db_backend {
-    if [ "$VITRAGE_DATABASE" = 'mysql' ] || [ "$VITRAGE_DATABASE" = 'postgresql' ] ; then
+    if [[ "$VITRAGE_DATABASE" = 'mysql' ]] || [[ "$VITRAGE_DATABASE" = 'postgresql' ]] ; then
         iniset $VITRAGE_CONF database connection $(database_connection_url vitrage)
     else
         die $LINENO "Unable to configure unknown VITRAGE_DATABASE $VITRAGE_DATABASE"
@@ -150,14 +147,12 @@ function configure_vitrage {
     iniset $VITRAGE_CONF DEFAULT debug "$ENABLE_DEBUG_LOG_LEVEL"
 
     # Set up logging
-    if [ "$SYSLOG" != "False" ]; then
+    if [[ "$SYSLOG" != "False" ]]; then
         iniset $VITRAGE_CONF DEFAULT use_syslog "True"
     fi
 
     # Format logging
-    if [ "$LOG_COLOR" == "True" ] && [ "$SYSLOG" == "False" ] && [ "$VITRAGE_DEPLOY" != "mod_wsgi" ]; then
-        setup_colorized_logging $VITRAGE_CONF DEFAULT
-    fi
+    setup_logging $VITRAGE_CONF
 
     cp $VITRAGE_DIR/etc/vitrage/api-paste.ini $VITRAGE_CONF_DIR
 
@@ -189,11 +184,36 @@ function configure_vitrage {
         disable_vitrage_datasource heat.stack
     fi
 
+    # remove trove vitrage datasource if trove datasource not installed
+    if ! is_service_enabled trove; then
+        disable_vitrage_datasource trove.instance trove.cluster
+    fi
+
+    # remove monasca vitrage datasource if nagios datasource not installed
+    if ! is_service_enabled monasca; then
+        disable_vitrage_datasource monasca
+    fi
+
     # remove nagios vitrage datasource if nagios datasource not installed
-    if [ "$VITRAGE_USE_NAGIOS" == "False" ]; then
+    if [[ "$VITRAGE_USE_NAGIOS" == "False" ]]; then
         disable_vitrage_datasource nagios
     fi
 
+    # remove static vitrage datasource if it's not enabled
+    if [[ "$VITRAGE_USE_STATIC" == "False" ]]; then
+        disable_vitrage_datasource static
+    fi
+
+    # remove doctor vitrage datasource if it's not enabled
+    if [[ "$VITRAGE_USE_DOCTOR" == "False" ]]; then
+        disable_vitrage_datasource doctor
+    fi
+
+    # remove prometheus vitrage datasource if it's not enabled
+    if [[ "$VITRAGE_USE_PROMETHEUS" == "False" ]]; then
+        disable_vitrage_datasource prometheus
+    fi
+
     # add default datasources
     iniset $VITRAGE_CONF datasources types $VITRAGE_DEFAULT_DATASOURCES
 
@@ -211,32 +231,16 @@ function configure_vitrage {
     iniset $VITRAGE_CONF "keystone_authtoken" project_name $admin_project_name
     iniset $VITRAGE_CONF "keystone_authtoken" project_domain_name $admin_domain_name
 
-    if [ "$VITRAGE_DEPLOY" == "mod_wsgi" ]; then
+    if [[ "$VITRAGE_DEPLOY" == "mod_wsgi" ]]; then
         _vitrage_config_apache_wsgi
-    elif [ "$VITRAGE_DEPLOY" == "uwsgi" ]; then
-        # iniset creates these files when it's called if they don't exist.
-        VITRAGE_UWSGI_FILE=$VITRAGE_CONF_DIR/vitrage-uwsgi.ini
+    else
+        write_uwsgi_config "$VITRAGE_UWSGI_FILE" "$VITRAGE_PUBLIC_UWSGI" "/rca"
+    fi
 
-        rm -f "$VITRAGE_UWSGI_FILE"
-
-        iniset "$VITRAGE_UWSGI_FILE" uwsgi http $VITRAGE_SERVICE_HOST:$VITRAGE_SERVICE_PORT
-        iniset "$VITRAGE_UWSGI_FILE" uwsgi wsgi-file "$VITRAGE_DIR/vitrage/api/app.wsgi"
-        # This is running standalone
-        iniset "$VITRAGE_UWSGI_FILE" uwsgi master true
-        # Set die-on-term & exit-on-reload so that uwsgi shuts down
-        iniset "$VITRAGE_UWSGI_FILE" uwsgi die-on-term true
-        iniset "$VITRAGE_UWSGI_FILE" uwsgi exit-on-reload true
-        iniset "$VITRAGE_UWSGI_FILE" uwsgi threads 10
-        iniset "$VITRAGE_UWSGI_FILE" uwsgi processes $API_WORKERS
-        iniset "$VITRAGE_UWSGI_FILE" uwsgi enable-threads true
-        iniset "$VITRAGE_UWSGI_FILE" uwsgi plugins python
-        iniset "$VITRAGE_UWSGI_FILE" uwsgi lazy-apps true
-        # uwsgi recommends this to prevent thundering herd on accept.
-        iniset "$VITRAGE_UWSGI_FILE" uwsgi thunder-lock true
-        # Override default size for headers from the 4k default.
-        iniset "$VITRAGE_UWSGI_FILE" uwsgi buffer-size 65535
-        # Make sure client doesn't try to re-use the connection.
-        iniset "$VITRAGE_UWSGI_FILE" uwsgi add-header "Connection: close"
+    if [[ ! -z "$VITRAGE_COORDINATION_URL" ]]; then
+        iniset $VITRAGE_CONF coordination backend_url "$VITRAGE_COORDINATION_URL"
+    elif is_service_enabled etcd3; then
+        iniset $VITRAGE_CONF coordination backend_url "etcd3://${SERVICE_HOST}:$ETCD_PORT"
     fi
 }
 
@@ -247,7 +251,7 @@ function init_vitrage {
 
     # Create and upgrade database only when used
     if is_service_enabled mysql postgresql; then
-        if [ "$VITRAGE_DATABASE" = 'mysql' ] || [ "$VITRAGE_DATABASE" = 'postgresql' ] ; then
+        if [[ "$VITRAGE_DATABASE" = 'mysql' ]] || [[ "$VITRAGE_DATABASE" = 'postgresql' ]] ; then
             recreate_database vitrage
             $VITRAGE_BIN_DIR/vitrage-dbsync
         fi
@@ -264,9 +268,9 @@ function install_vitrage {
     setup_develop "$VITRAGE_DIR"
     sudo install -d -o $STACK_USER -m 755 $VITRAGE_CONF_DIR
 
-    if [ "$VITRAGE_DEPLOY" == "mod_wsgi" ]; then
+    if [[ "$VITRAGE_DEPLOY" == "mod_wsgi" ]]; then
         install_apache_wsgi
-    elif [ "$VITRAGE_DEPLOY" == "uwsgi" ]; then
+    elif [[ "$VITRAGE_DEPLOY" == "uwsgi" ]]; then
         pip_install uwsgi
     fi
 }
@@ -287,8 +291,8 @@ function start_vitrage {
     if [[ "$VITRAGE_DEPLOY" == "mod_wsgi" ]]; then
         enable_apache_site vitrage
         restart_apache_server
-    elif [ "$VITRAGE_DEPLOY" == "uwsgi" ]; then
-        run_process vitrage-api "$VITRAGE_BIN_DIR/uwsgi $VITRAGE_UWSGI_FILE"
+    elif [[ "$VITRAGE_DEPLOY" == "uwsgi" ]]; then
+        run_process vitrage-api "$VITRAGE_BIN_DIR/uwsgi --procname-prefix vitrage --ini $VITRAGE_UWSGI_FILE" ""
     else
         run_process vitrage-api "$VITRAGE_BIN_DIR/vitrage-api -d -v --config-file $VITRAGE_CONF"
     fi
@@ -301,33 +305,17 @@ function start_vitrage {
         fi
     fi
 
-    run_process vitrage-collector "$VITRAGE_BIN_DIR/vitrage-collector --config-file $VITRAGE_CONF"
     run_process vitrage-graph "$VITRAGE_BIN_DIR/vitrage-graph --config-file $VITRAGE_CONF"
     run_process vitrage-notifier "$VITRAGE_BIN_DIR/vitrage-notifier --config-file $VITRAGE_CONF"
     run_process vitrage-ml "$VITRAGE_BIN_DIR/vitrage-ml --config-file $VITRAGE_CONF"
     run_process vitrage-persistor "$VITRAGE_BIN_DIR/vitrage-persistor --config-file $VITRAGE_CONF"
     run_process vitrage-snmp-parsing "$VITRAGE_BIN_DIR/vitrage-snmp-parsing --config-file $VITRAGE_CONF"
 
-    write_systemd_dependency vitrage-graph vitrage-collector
 
     change_systemd_kill_mode vitrage-graph
-    change_systemd_kill_mode vitrage-collector
 }
 
 
-function write_systemd_dependency {
-  local service_after=$1
-  local service_before=$2
-  local systemd_service_after="devstack@$service_after.service"
-  local systemd_service_before="devstack@$service_before.service"
-
-  local unitfile_after="$SYSTEMD_DIR/$systemd_service_after"
-
-  iniset -sudo $unitfile_after "Unit" "After" "$systemd_service_before"
-
-  $SYSTEMCTL daemon-reload
-}
-
 function change_systemd_kill_mode {
    local service=$1
    local systemd_service="devstack@$service.service"
@@ -340,11 +328,11 @@ function change_systemd_kill_mode {
 
 # stop_vitrage() - Stop running processes
 function stop_vitrage {
-    if [ "$VITRAGE_DEPLOY" == "mod_wsgi" ]; then
+    if [[ "$VITRAGE_DEPLOY" == "mod_wsgi" ]]; then
         disable_apache_site vitrage
         restart_apache_server
     fi
-    for serv in vitrage-api vitrage-collector vitrage-graph vitrage-notifier vitrage-persistor vitrage-ml vitrage-snmp-parsing; do
+    for serv in vitrage-api vitrage-graph vitrage-notifier vitrage-persistor vitrage-ml vitrage-snmp-parsing; do
         stop_process $serv
     done
 }
@@ -359,6 +347,12 @@ function modify_heat_global_index_policy_rule {
     fi
 }
 
+function add_monasca_rule_to_vitrage {
+    if is_service_enabled monasca; then
+       get_or_add_user_project_role "monasca-read-only-user" "vitrage" "admin"
+    fi
+}
+
 # This is the main for plugin.sh
 if is_service_enabled vitrage; then
     if [[ "$1" == "stack" && "$2" == "pre-install" ]]; then
@@ -378,6 +372,9 @@ if is_service_enabled vitrage; then
         modify_heat_global_index_policy_rule
         # Tidy base for vitrage
         init_vitrage
+        # add monasca-read-only-user role to vitrage user so
+        # vitrage user can read monasca alarms
+        add_monasca_rule_to_vitrage
         # Start the services
         start_vitrage
     fi
