@@ -13,8 +13,8 @@
 # under the License.
 
 from datetime import timedelta
-import time
 
+from oslo_config import cfg
 from oslo_log import log
 
 from vitrage.common.constants import DatasourceAction
@@ -31,18 +31,17 @@ from vitrage.evaluator.actions.evaluator_event_transformer \
 from vitrage.messaging import VitrageNotifier
 from vitrage.utils.datetime import utcnow
 
+CONF = cfg.CONF
 LOG = log.getLogger(__name__)
 
 
 class ConsistencyEnforcer(object):
 
     def __init__(self,
-                 conf,
                  entity_graph,
                  actions_callback=None):
-        self.conf = conf
         self.actions_callback = actions_callback or VitrageNotifier(
-            conf, 'vitrage_consistency', [EVALUATOR_TOPIC]).notify
+            'vitrage_consistency', [EVALUATOR_TOPIC]).notify
         self.graph = entity_graph
         self._init_datasources_to_mark_deleted()
 
@@ -52,23 +51,29 @@ class ConsistencyEnforcer(object):
             LOG.info('Periodic consistency check..')
 
             old_deleted_entities = self._find_old_deleted_entities()
-            LOG.debug('Found %s vertices to be deleted by consistency service'
-                      ': %s', len(old_deleted_entities), old_deleted_entities)
+            if old_deleted_entities:
+                LOG.info('Consistency will remove %s deleted entities',
+                         len(old_deleted_entities))
+                LOG.debug('Consistency entities to remove: %s',
+                          old_deleted_entities)
             self._push_events_to_queue(old_deleted_entities,
                                        GraphAction.REMOVE_DELETED_ENTITY)
 
             stale_entities = self._find_outdated_entities_to_mark_as_deleted()
-            LOG.debug('Found %s outdated vertices to be marked as deleted '
-                      'by the consistency service: %s', len(stale_entities),
-                      stale_entities)
+            if stale_entities:
+                LOG.info('Consistency will mark %s entities as deleted',
+                         len(stale_entities))
+                LOG.debug('Consistency entities to mark deleted: %s',
+                          stale_entities)
             self._push_events_to_queue(stale_entities,
                                        GraphAction.DELETE_ENTITY)
+            LOG.info('Periodic consistency check done.')
         except Exception:
             LOG.exception('Error in deleting vertices from entity_graph.')
 
     def _find_outdated_entities_to_mark_as_deleted(self):
         vitrage_sample_tstmp = str(utcnow() - timedelta(
-            seconds=2 * self.conf.datasources.snapshots_interval))
+            seconds=2 * CONF.datasources.snapshots_interval))
         query = {
             'and': [
                 {'!=': {VProps.VITRAGE_TYPE: VITRAGE_DATASOURCE}},
@@ -82,7 +87,7 @@ class ConsistencyEnforcer(object):
 
     def _find_old_deleted_entities(self):
         vitrage_sample_tstmp = str(utcnow() - timedelta(
-            seconds=self.conf.consistency.min_time_to_delete))
+            seconds=CONF.consistency.min_time_to_delete))
         query = {
             'and': [
                 {'==': {VProps.VITRAGE_IS_DELETED: True}},
@@ -95,6 +100,7 @@ class ConsistencyEnforcer(object):
         return self._filter_vertices_to_be_deleted(vertices)
 
     def _push_events_to_queue(self, vertices, action):
+        events = []
         for vertex in vertices:
             event = {
                 DSProps.ENTITY_TYPE: CONSISTENCY_DATASOURCE,
@@ -107,7 +113,8 @@ class ConsistencyEnforcer(object):
                 VProps.VITRAGE_CATEGORY: vertex[VProps.VITRAGE_CATEGORY],
                 VProps.IS_REAL_VITRAGE_ID: True
             }
-            self.actions_callback('consistency', event)
+            events.append(event)
+        self.actions_callback('consistency', events)
 
     @staticmethod
     def _filter_vertices_to_be_deleted(vertices):
@@ -130,26 +137,15 @@ class ConsistencyEnforcer(object):
                (vertex.get(VProps.VITRAGE_DATASOURCE_NAME) in
                 self.datasources_to_mark_deleted)
 
-    def _wait_for_action(self, function):
-        count_retries = 0
-        while True:
-            if count_retries >= \
-                    self.conf.consistency.initialization_max_retries:
-                return False
-
-            if function():
-                return True
-
-            count_retries += 1
-            time.sleep(self.conf.consistency.initialization_interval)
-
     def _init_datasources_to_mark_deleted(self):
         self.datasources_to_mark_deleted = []
 
-        for driver_name in self.conf.datasources.types:
-            driver_class = utils.get_driver_class(self.conf, driver_name)
+        for driver_name in CONF.datasources.types:
+            driver_class = utils.get_driver_class(driver_name)
             if driver_class.should_delete_outdated_entities():
                 self.datasources_to_mark_deleted.append(driver_name)
 
-        LOG.info('Vertices of the following datasources will be deleted if '
-                 'they become outdated: %s', self.datasources_to_mark_deleted)
+        if self.datasources_to_mark_deleted:
+            LOG.info('Vertices of the following datasources will be deleted if'
+                     'they become outdated: %s',
+                     self.datasources_to_mark_deleted)
