@@ -12,7 +12,6 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-from oslo_config import cfg
 from six.moves import queue
 
 from vitrage.common.constants import DatasourceAction
@@ -38,6 +37,7 @@ from vitrage.evaluator.actions.evaluator_event_transformer \
     import VITRAGE_DATASOURCE
 from vitrage.evaluator.actions.recipes.action_steps import ADD_VERTEX
 from vitrage.evaluator.actions.recipes.base import EVALUATOR_EVENT_TYPE
+from vitrage.evaluator.scenario_evaluator import ActionInfo
 from vitrage.evaluator.template_data import ActionSpecs
 from vitrage.evaluator.template_fields import TemplateFields as TFields
 from vitrage.opts import register_opts
@@ -47,17 +47,12 @@ from vitrage.tests.functional.test_configuration import TestConfiguration
 
 class TestActionExecutor(TestFunctionalBase, TestConfiguration):
 
-    # noinspection PyPep8Naming
-    @classmethod
-    def setUpClass(cls):
-        super(TestActionExecutor, cls).setUpClass()
-        cls.conf = cfg.ConfigOpts()
-        cls.conf.register_opts(cls.PROCESSOR_OPTS, group='entity_graph')
-        cls.conf.register_opts(cls.DATASOURCES_OPTS, group='datasources')
-        cls.add_db(cls.conf)
+    def setUp(self):
+        super(TestActionExecutor, self).setUp()
+        self.add_db()
 
-        for vitrage_type in cls.conf.datasources.types:
-            register_opts(cls.conf, vitrage_type, cls.conf.datasources.path)
+        for datasource_name in self.conf.datasources.types:
+            register_opts(datasource_name, self.conf.datasources.path)
 
     def _init_executer(self):
         event_queue = queue.Queue()
@@ -65,12 +60,12 @@ class TestActionExecutor(TestFunctionalBase, TestConfiguration):
         def actions_callback(event_type, data):
             event_queue.put(data)
 
-        return event_queue, ActionExecutor(self.conf, actions_callback)
+        return event_queue, ActionExecutor(actions_callback)
 
     def test_execute_set_state(self):
 
         # Test Setup
-        processor = self._create_processor_with_graph(self.conf)
+        processor = self._create_processor_with_graph()
 
         vertex_attrs = {VProps.VITRAGE_TYPE: NOVA_HOST_DATASOURCE}
         host_vertices = processor.entity_graph.get_vertices(
@@ -84,8 +79,9 @@ class TestActionExecutor(TestFunctionalBase, TestConfiguration):
         event_queue, action_executor = self._init_executer()
 
         # Test Action - do
-        action_executor.execute(action_spec, ActionMode.DO)
-        processor.process_event(event_queue.get())
+        action_executor.execute(
+            [ActionInfo(action_spec, ActionMode.DO, None, None)])
+        self._consume_queue(event_queue, processor)
 
         host_vertex_after = processor.entity_graph.get_vertex(
             host_vertex_before.vertex_id)
@@ -104,8 +100,9 @@ class TestActionExecutor(TestFunctionalBase, TestConfiguration):
         self.assertEqual(v_state_after, OperationalResourceState.SUBOPTIMAL)
 
         # Test Action - undo
-        action_executor.execute(action_spec, ActionMode.UNDO)
-        processor.process_event(event_queue.get())
+        action_executor.execute(
+            [ActionInfo(action_spec, ActionMode.UNDO, None, None)])
+        self._consume_queue(event_queue, processor)
 
         host_vertex_after_undo = processor.entity_graph.get_vertex(
             host_vertex_before.vertex_id)
@@ -120,7 +117,7 @@ class TestActionExecutor(TestFunctionalBase, TestConfiguration):
     def test_execute_mark_instance_down(self):
 
         # Test Setup
-        processor = self._create_processor_with_graph(self.conf)
+        processor = self._create_processor_with_graph()
 
         vertex_attrs = {VProps.VITRAGE_TYPE: NOVA_INSTANCE_DATASOURCE}
         instance_vertices = processor.entity_graph.get_vertices(
@@ -134,8 +131,9 @@ class TestActionExecutor(TestFunctionalBase, TestConfiguration):
         event_queue, action_executor = self._init_executer()
 
         # Test Action - do
-        action_executor.execute(action_spec, ActionMode.DO)
-        processor.process_event(event_queue.get())
+        action_executor.execute(
+            [ActionInfo(action_spec, ActionMode.DO, None, None)])
+        self._consume_queue(event_queue, processor)
 
         instance_vertex_after = processor.entity_graph.get_vertex(
             instance_vertex_before.vertex_id)
@@ -144,8 +142,9 @@ class TestActionExecutor(TestFunctionalBase, TestConfiguration):
         self.assertTrue(instance_vertex_after.get(VProps.IS_MARKED_DOWN))
 
         # Test Action - undo
-        action_executor.execute(action_spec, ActionMode.UNDO)
-        processor.process_event(event_queue.get())
+        action_executor.execute(
+            [ActionInfo(action_spec, ActionMode.UNDO, None, None)])
+        self._consume_queue(event_queue, processor)
 
         instance_vertex_after_undo = processor.entity_graph.get_vertex(
             instance_vertex_before.vertex_id)
@@ -156,7 +155,7 @@ class TestActionExecutor(TestFunctionalBase, TestConfiguration):
     def test_execute_mark_down(self):
 
         # Test Setup
-        processor = self._create_processor_with_graph(self.conf)
+        processor = self._create_processor_with_graph()
 
         vertex_attrs = {VProps.VITRAGE_TYPE: NOVA_HOST_DATASOURCE}
         host_vertices = processor.entity_graph.get_vertices(
@@ -170,8 +169,9 @@ class TestActionExecutor(TestFunctionalBase, TestConfiguration):
         event_queue, action_executor = self._init_executer()
 
         # Test Action - do
-        action_executor.execute(action_spec, ActionMode.DO)
-        processor.process_event(event_queue.get())
+        action_executor.execute(
+            [ActionInfo(action_spec, ActionMode.DO, None, None)])
+        self._consume_queue(event_queue, processor)
 
         host_vertex_after = processor.entity_graph.get_vertex(
             host_vertex_before.vertex_id)
@@ -180,8 +180,9 @@ class TestActionExecutor(TestFunctionalBase, TestConfiguration):
         self.assertTrue(host_vertex_after.get(VProps.IS_MARKED_DOWN))
 
         # Test Action - undo
-        action_executor.execute(action_spec, ActionMode.UNDO)
-        processor.process_event(event_queue.get())
+        action_executor.execute(
+            [ActionInfo(action_spec, ActionMode.UNDO, None, None)])
+        self._consume_queue(event_queue, processor)
 
         host_vertex_after_undo = processor.entity_graph.get_vertex(
             host_vertex_before.vertex_id)
@@ -192,7 +193,7 @@ class TestActionExecutor(TestFunctionalBase, TestConfiguration):
     def test_execute_add_edge(self):
 
         # Test Setup
-        processor = self._create_processor_with_graph(self.conf)
+        processor = self._create_processor_with_graph()
 
         vertex_attrs = {VProps.VITRAGE_TYPE: NOVA_HOST_DATASOURCE}
         host_vertices = processor.entity_graph.get_vertices(
@@ -227,8 +228,9 @@ class TestActionExecutor(TestFunctionalBase, TestConfiguration):
                                                       alarm1.vertex_id,
                                                       EdgeLabel.CAUSES)
         # Test Action - do
-        action_executor.execute(action_spec, ActionMode.DO)
-        processor.process_event(event_queue.get())
+        action_executor.execute(
+            [ActionInfo(action_spec, ActionMode.DO, None, None)])
+        self._consume_queue(event_queue, processor)
 
         new_edge = processor.entity_graph.get_edge(alarm2.vertex_id,
                                                    alarm1.vertex_id,
@@ -240,7 +242,7 @@ class TestActionExecutor(TestFunctionalBase, TestConfiguration):
     def test_execute_add_vertex(self):
 
         # Test Setup
-        processor = self._create_processor_with_graph(self.conf)
+        processor = self._create_processor_with_graph()
 
         vertex_attrs = {VProps.VITRAGE_TYPE: NOVA_HOST_DATASOURCE}
         host_vertices = processor.entity_graph.get_vertices(
@@ -267,8 +269,9 @@ class TestActionExecutor(TestFunctionalBase, TestConfiguration):
         event_queue, action_executor = self._init_executer()
 
         # Test Action
-        action_executor.execute(action_spec, ActionMode.DO)
-        processor.process_event(event_queue.get())
+        action_executor.execute(
+            [ActionInfo(action_spec, ActionMode.DO, None, None)])
+        self._consume_queue(event_queue, processor)
 
         after_alarms = processor.entity_graph.get_vertices(
             vertex_attr_filter=alarm_vertex_attrs)
@@ -298,7 +301,7 @@ class TestActionExecutor(TestFunctionalBase, TestConfiguration):
     def test_execute_add_and_remove_vertex(self):
 
         # Test Setup
-        processor = self._create_processor_with_graph(self.conf)
+        processor = self._create_processor_with_graph()
 
         vertex_attrs = {VProps.VITRAGE_TYPE: NOVA_HOST_DATASOURCE}
         host_vertices = processor.entity_graph.get_vertices(
@@ -330,9 +333,9 @@ class TestActionExecutor(TestFunctionalBase, TestConfiguration):
         event_queue, action_executor = self._init_executer()
 
         # Test Action - undo
-        action_executor.execute(action_spec, ActionMode.UNDO)
-        event = event_queue.get()
-        processor.process_event(event)
+        action_executor.execute(
+            [ActionInfo(action_spec, ActionMode.UNDO, None, None)])
+        self._consume_queue(event_queue, processor)
 
         after_alarms = processor.entity_graph.get_vertices(
             vertex_attr_filter=alarm_vertex_attrs)
