@@ -27,11 +27,12 @@ from vitrage.evaluator.template_data import ActionSpecs
 from vitrage.evaluator.template_data import EdgeDescription
 from vitrage.evaluator.template_data import Scenario
 from vitrage.evaluator.template_fields import TemplateFields as TFields
-from vitrage.evaluator.template_loading.template_loader import TemplateLoader
+from vitrage.evaluator.template_loading.props_converter import PropsConverter
 from vitrage.graph import Edge
 from vitrage.graph import Vertex
 from vitrage.tests import base
 from vitrage.tests.mocks import utils
+from vitrage.tests.unit.evaluator import get_template_data
 from vitrage.utils import file as file_utils
 
 
@@ -52,12 +53,12 @@ class TemplateLoaderTest(base.BaseTest):
         template_definition = file_utils.load_yaml_file(template_path, True)
         def_templates_path = self.DEF_TEMPLATE_TESTS_DIR + \
             '/definition_templates'
-        def_demplates_list = file_utils.load_yaml_files(
+        def_templates_list = file_utils.load_yaml_files(
             def_templates_path)
         def_templates_dict = utils.get_def_templates_dict_from_list(
-            def_demplates_list)
-        template_data = \
-            TemplateLoader().load(template_definition, def_templates_dict)
+            def_templates_list)
+        template_data = get_template_data(template_definition,
+                                          def_templates_dict)
         entities = template_data.entities
         relationships = template_data.relationships
         scenarios = template_data.scenarios
@@ -74,8 +75,8 @@ class TemplateLoaderTest(base.BaseTest):
         # Assertions
         for definition in definitions[TFields.ENTITIES]:
             for key, value in definition['entity'].items():
-                new_key = TemplateLoader.PROPS_CONVERSION[key] if key in \
-                    TemplateLoader.PROPS_CONVERSION else key
+                new_key = PropsConverter.PROPS_CONVERSION[key] \
+                    if key in PropsConverter.PROPS_CONVERSION else key
                 del definition['entity'][key]
                 definition['entity'][new_key] = value
         self._validate_entities(entities, definitions[TFields.ENTITIES])
@@ -164,7 +165,7 @@ class TemplateLoaderTest(base.BaseTest):
                                                      self.BASIC_TEMPLATE)
         template_definition = file_utils.load_yaml_file(template_path, True)
 
-        template_data = TemplateLoader().load(template_definition)
+        template_data = get_template_data(template_definition)
         entities = template_data.entities
         relationships = template_data.relationships
         scenarios = template_data.scenarios
@@ -173,8 +174,8 @@ class TemplateLoaderTest(base.BaseTest):
         # Assertions
         for definition in definitions[TFields.ENTITIES]:
             for key, value in definition['entity'].items():
-                new_key = TemplateLoader.PROPS_CONVERSION[key] if key in \
-                    TemplateLoader.PROPS_CONVERSION else key
+                new_key = PropsConverter.PROPS_CONVERSION[key] \
+                    if key in PropsConverter.PROPS_CONVERSION else key
                 del definition['entity'][key]
                 definition['entity'][new_key] = value
         self._validate_entities(entities, definitions[TFields.ENTITIES])
@@ -248,7 +249,7 @@ class TemplateLoaderTest(base.BaseTest):
         template_path = '%s/templates/version/%s' % (utils.get_resources_dir(),
                                                      template_file)
         template_definition = file_utils.load_yaml_file(template_path, True)
-        template_data = TemplateLoader().load(template_definition)
+        template_data = get_template_data(template_definition)
         scenarios = template_data.scenarios
         self.assertIsNotNone(scenarios, 'Template should include a scenario')
         self.assertThat(scenarios, matchers.HasLength(1),
